==> haskell-hsopenssl-x509-system-0.1.0.4-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsOpenSSL-x509-system
version:              0.1.0.4
visibility:           public
id:                   HsOpenSSL-x509-system-0.1.0.4-GajISfcWdBOKCIXrCE0rXt
key:                  HsOpenSSL-x509-system-0.1.0.4-GajISfcWdBOKCIXrCE0rXt
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/HsOpenSSL-x509-system
synopsis:             Use the system'\''s native CA certificate store with HsOpenSSL
description:
    A cross-platform library that tries to find a (reasonable) CA certificate
    bundle that can be used with @HsOpenSSL@ to verify the certificates of
    remote peers.

    This package is for @HsOpenSSL@ what @x509-system@ is for the @tls@ package.
    Additionally, it borrows some ideas from @x509-system@.

category:             System, Filesystem
abi:                  c0707ca94a02ebf37911479e801ffbec
exposed:              True
exposed-modules:      OpenSSL.X509.SystemStore
hidden-modules:       OpenSSL.X509.SystemStore.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsopenssl-x509-system
hs-libraries:         HSHsOpenSSL-x509-system-0.1.0.4-GajISfcWdBOKCIXrCE0rXt
depends:
    HsOpenSSL-0.11.7.9-2dJWTXbGJ2o2w7V8hugDcS base-4.17.2.1
    bytestring-0.11.5.3 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-hsopenssl-x509-system/html/HsOpenSSL-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-hsopenssl-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-x509-system-0.1.0.4-142-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsOpenSSL-x509-system
version:              0.1.0.4
visibility:           public
id:                   HsOpenSSL-x509-system-0.1.0.4-xkoU2BELOD1sVoZi1ETNm
key:                  HsOpenSSL-x509-system-0.1.0.4-xkoU2BELOD1sVoZi1ETNm
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/HsOpenSSL-x509-system
synopsis:             Use the system'\''s native CA certificate store with HsOpenSSL
description:
    A cross-platform library that tries to find a (reasonable) CA certificate
    bundle that can be used with @HsOpenSSL@ to verify the certificates of
    remote peers.

    This package is for @HsOpenSSL@ what @x509-system@ is for the @tls@ package.
    Additionally, it borrows some ideas from @x509-system@.

category:             System, Filesystem
abi:                  8a6964d8151f3b5f28f698b5b1512dc8
exposed:              True
exposed-modules:      OpenSSL.X509.SystemStore
hidden-modules:       OpenSSL.X509.SystemStore.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsopenssl-x509-system
hs-libraries:         HSHsOpenSSL-x509-system-0.1.0.4-xkoU2BELOD1sVoZi1ETNm
depends:
    HsOpenSSL-0.11.7.9-ABz2mAiFhzZJZi7dc04UNa base-4.17.2.1
    bytestring-0.11.5.3 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-hsopenssl-x509-system/html/HsOpenSSL-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-hsopenssl-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
